@@ -1,5 +1,8 @@
-# This file was created automatically by SWIG.
+# This file was created automatically by SWIG 1.3.27.
 # Don't modify this file, modify the SWIG interface instead.
+
+import _pycdio
+
 # This file is compatible with both classic and new-style classes.
 
 """
@@ -8,9 +11,6 @@ encapsulates CD-ROM reading and control. Python programs wishing to be
 oblivious of the OS- and device-dependent properties of a CD-ROM can
 use this library.
 """
-
-import _pycdio
-
 def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
     if (name == "this"):
         if isinstance(value, class_type):
@@ -293,13 +293,27 @@ def get_track_lsn(*args):
     """
     return _pycdio.get_track_lsn(*args)
 
+def get_track_msf(*args):
+    """
+    get_track_msf(cdio,track)->string
+
+      Return the starting MSF (minutes/secs/frames) for track number
+      track.  Track numbers usually start at something 
+      greater than 0, usually 1.
+
+      The 'leadout' track is specified either by
+      using i_track CDIO_CDROM_LEADOUT_TRACK or the total tracks+1.
+        
+    @return string mm:ss:ff if all good, or string 'error' on error.
+    """
+    return _pycdio.get_track_msf(*args)
+
 def get_track_preemphasis(*args):
     """
     cdio_get_track_preemphasis(cdio, track)
 
     Get linear preemphasis status on an audio track.
     This is not meaningful if not an audio track?
-
     """
     return _pycdio.get_track_preemphasis(*args)
 
@@ -722,7 +736,7 @@ def get_disc_mode(*args):
     """
     get_disc_mode(p_cdio) -> str
 
-    Get disc mode - the kind of CD (CD-DA, CD-ROM mode 1, CD-MIXED, etc.
+    Get disc mode - the kind of CD (CD-DA, CD-ROM mode 1, CD-MIXED, ...)
     that we've got. The notion of 'CD' is extended a little to include
     DVD's.
     """
@@ -756,6 +770,7 @@ def get_num_tracks(*args):
     return _pycdio.get_num_tracks(*args)
 INCLUDE_CLASS = _pycdio.INCLUDE_CLASS
 
+
 def get_drive_cap(*args):
     """
     get_drive_cap()->(read_cap, write_cap, misc_cap)
